#' @title Chr. basic data Holo.
#'
#' @docType data
#' @name chrbasicdataHolo
NULL
#' @description dfChrSizeHolo: Example data for holocentrics for 1 species
#'
#' @format data.frame with cols:
#' \describe{
#'   \item{OTU}{grouping OTU (species), optional if only one OTU}
#'   \item{chrName}{name of chromosome}
#'   \item{chrSize}{size of chromosome, micrometers or Mb}
#'   \item{group}{chromosome group, optional}
#' }
#' @seealso \code{\link{asymmetryA2}}
#' @seealso \code{\link{plotIdiograms}}
#' @seealso \code{\link{markdataholo}}
#'
#' @rdname chrbasicdataHolo
"dfChrSizeHolo"
#' @description bigdfChrSizeHolo: Example data for holocentrics for several species, OTU
#' @rdname chrbasicdataHolo
"bigdfChrSizeHolo"
#' @description parentalAndHybHoloChrSize: Example data for holocentrics for several species, OTU
#' @rdname chrbasicdataHolo
"parentalAndHybHoloChrSize"
